@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Patch.py 12048 2020-04-06 10:51:25Z Trista $
+# $Id: Patch.py 12213 2020-05-13 14:02:01Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Trista $ (last)
-# $Date: 2020-04-06 18:51:25 +0800 (週一, 06 四月 2020) $
-# $Revision: 12048 $
+# $Author: Lavender $ (last)
+# $Date: 2020-05-13 23:02:01 +0900 (週三, 13 五月 2020) $
+# $Revision: 12213 $
 #
 # Contributors:
 #  Bear
@@ -240,6 +240,16 @@ def attachURLs(settings, urlpatterns):
             url(r'^metrics/send/', sendStatsd, name='sendStatsd'),
             url(r'^metrics/image/', getStatsdImage, name='getStatsdImage'),
         )
+        
+    addTestUrl = False
+    if hasattr(settings ,'IUNO_TEST_ENABLE'):
+        addTestUrl = settings.IUNO_TEST_ENABLE
+        
+    if addTestUrl:
+        from Iuno.test.views import test
+        urlpatterns += patterns('',
+            url(r"^remote/test/$", test, name="remoteTest"),
+        )
     
     if settings.DEBUG == False and settings.SERVER_MODE == settings.DEVELOPMENT:
         if DJANGO_VERSION >= 11100: # django >= 1.11
