@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 11355 2019-01-29 12:31:18Z Lavender $
+# $Id: models.py 11930 2020-02-18 16:03:26Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-01-29 20:31:18 +0800 (週二, 29 一月 2019) $
-# $Revision: 11355 $
+# $Date: 2020-02-19 01:03:26 +0900 (週三, 19 二月 2020) $
+# $Revision: 11930 $
 
 import os
 import hashlib
@@ -37,7 +37,7 @@ TYPE_CHOICES = (
 )
 
 class Version(models.Model):
-    dirName = models.CharField(max_length=32) # md5(path)
+    dirName = models.CharField(max_length=32, db_index=True) # md5(path)
     fileName = models.CharField(max_length=256)
 
     number = models.PositiveIntegerField() 
@@ -76,8 +76,7 @@ class Version(models.Model):
 class VersionControlMixin(object):
     def getVersion(self, versionNumber=None):
         if self.type == FILE:
-            path = self.path
-            dirName = hashlib.md5(toBytes(path)).hexdigest()
+            dirName = self.dirName
 
             if Version.objects.filter(dirName=dirName).exists():
                 if versionNumber:
@@ -96,6 +95,10 @@ class VersionControlMixin(object):
     @property
     def version(self):
         return self.getVersion()
+        
+    @property
+    def dirName(self):
+        return hashlib.md5(toBytes(self.path)).hexdigest()
 
 class Static(MPTTModel, VersionControlMixin):
     type = models.IntegerField(choices=TYPE_CHOICES)
